<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<context>
    <name>AlterTableDialog</name>
    <message>
        <location filename="../altertabledialog.cpp" line="27"/>
        <source>Alte&amp;r</source>
        <translation>&amp;Zmień</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="47"/>
        <source>Alter Table</source>
        <translation>Zmień tabelę</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="73"/>
        <source>Error while renaming table %1: %2.

%3</source>
        <translation>Wystąpił błąd podczas zmiany nazwy tabeli %1: %2.

%3</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="81"/>
        <source>Table renamed successfully</source>
        <translation>Nazwa tabeli została zmieniona</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="120"/>
        <source>Error while altering table %1: %2.
%3</source>
        <translation>Wystąpił błąd podczas zmian w tabeli %1: %2.

%3</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="124"/>
        <source>Table altered successfully</source>
        <translation>Tabela została zmieniona</translation>
    </message>
</context>
<context>
    <name>AlterTriggerDialog</name>
    <message>
        <location filename="../altertriggerdialog.cpp" line="23"/>
        <source>&amp;Alter</source>
        <translation>&amp;Zmień</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="31"/>
        <source>Cannot get trigger from the database.</source>
        <translation>Nie można znaleźć triggera w bazie.</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="51"/>
        <source>Cannot drop trigger: %1.

%2</source>
        <translation>Nie można usunąć triggera: %1.

%2</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="60"/>
        <source>Error while creating trigger: %2.

%3</source>
        <translation>Wystąpił błąd podczas tworzenia triggera: %2.

%3</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="63"/>
        <source>Trigger created successfully</source>
        <translation>Trigger został utworzony</translation>
    </message>
</context>
<context>
    <name>AlterViewDialog</name>
    <message>
        <location filename="../alterviewdialog.cpp" line="41"/>
        <source>Alter View</source>
        <translation>Zmiana Widoku</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="59"/>
        <source>Error while altering view (drop phase): %2.

%3</source>
        <translation type="obsolete">Wystąpił błąd podczas zmian w widoku (faza usuwania): %2.

%3</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="71"/>
        <source>Error while altering view: %2.

%3</source>
        <translation type="obsolete">Wystąpił błąd podczas zmian w widoku: %2.

%3</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="75"/>
        <source>View altered successfully</source>
        <translation>Widok został zmieniony</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="59"/>
        <source>Error while altering view (drop phase): %1.

%2</source>
        <translation>Wystąpił błąd podczas zmian w widoku (faza usuwania): %1.

%2</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="71"/>
        <source>Error while altering view: %1.

%2</source>
        <translation>Wystąpił błąd podczas zmian w widoku: %1.

%2</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <location filename="../analyzedialog.ui" line="13"/>
        <source>Analyze Database</source>
        <translation>Analiza bazy danych</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="25"/>
        <source>Compute Statistics for Selected Tables</source>
        <translation>Analizuj tylko zaznaczone tabele</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="44"/>
        <source>&amp;Compute</source>
        <translation>&amp;Analizuj</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="77"/>
        <source>Compute All Statistics</source>
        <translation>Analizuj wszystko</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="89"/>
        <source>Calculate &amp;All</source>
        <translation>Analizuj &amp;wszystko</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="109"/>
        <source>Recalculate the statistics for all objects in the DB.</source>
        <translation>Oblicza ponownie statystyki dla wszystkich obiektów bazy danych.</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="119"/>
        <source>Drop Statistics</source>
        <translation>Usuń statystyki</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="131"/>
        <source>&amp;Drop</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="151"/>
        <source>&lt;qt&gt;Statistics for all objects in the database will be dropped.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Statystyki wszystkich obiektów bazy danych zostana usunięte.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>ConstraintsDialog</name>
    <message>
        <location filename="../constraintsdialog.cpp" line="58"/>
        <source>Error while parsing constraints: %1.

%2</source>
        <translation>Wystąpił błąd podczas przetwarzania constraint: %1.

%2</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="127"/>
        <source>No action for INSERT</source>
        <translation>Brak działania dla INSERT</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="140"/>
        <source>No action for UPDATE</source>
        <translation>Brak działania dla UPDATE</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="153"/>
        <source>No action for DELETE</source>
        <translation>Brak działania dla DELETE</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="163"/>
        <source>Error while creating trigger: %1.</source>
        <translation>Wystąpił błąd podczas tworzenia triggera: %1.</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="165"/>
        <source>Trigger created successfully</source>
        <translation>Trigger został utworzony</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="13"/>
        <source>Constraints Triggers</source>
        <translation>Constraints Triggers</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="29"/>
        <source>&amp;Insert</source>
        <translation>&amp;Wstaw</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="110"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nazwa:</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="62"/>
        <source>&amp;Update</source>
        <translation>&amp;Aktualizuj</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="95"/>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="167"/>
        <source>C&amp;reate</source>
        <translation>U&amp;twórz</translation>
    </message>
</context>
<context>
    <name>CreateIndexDialog</name>
    <message>
        <location filename="../createindexdialog.cpp" line="76"/>
        <source>Error while creating index: %1
%2.</source>
        <translation>Wystąpił błąd podczas tworzenia indeksu: %1
%2.</translation>
    </message>
    <message>
        <location filename="../createindexdialog.cpp" line="80"/>
        <source>Index created successfully.</source>
        <translation>Indeks został utworzony.</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="13"/>
        <source>Create Index</source>
        <translation>Utwórz indeks</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="32"/>
        <source>Table Name:</source>
        <translation>Nazwa tabeli:</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="39"/>
        <source>Index &amp;Name:</source>
        <translation>Nazwa &amp;indeksu:</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="75"/>
        <source>&amp;Unique?</source>
        <translation>&amp;Niepowtarzalny?</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="104"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="97"/>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="136"/>
        <source>Column</source>
        <translation>Kolumna</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="141"/>
        <source>Use?</source>
        <translation>Użyć?</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="146"/>
        <source>Asc/Desc</source>
        <translation>Asc/Desc</translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="164"/>
        <source>C&amp;reate</source>
        <translation>U&amp;twórz</translation>
    </message>
</context>
<context>
    <name>CreateTableDialog</name>
    <message>
        <location filename="../createtabledialog.cpp" line="23"/>
        <source>Create Table</source>
        <translation>Utwórz tabelę</translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="72"/>
        <source>Error while creating table: %1.

%2</source>
        <translation>Wystąpił błąd podczas tworzenia tabeli: %1.

%2</translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="76"/>
        <source>Table created successfully</source>
        <translation>Tabela została utworzona</translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="83"/>
        <source>Sqliteman</source>
        <translation>Sqliteman</translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="85"/>
        <source>The current content of the Advanced SQL editor will be lost.Do you really want to recreate your SQL?</source>
        <translation>Aktualna zawartość edytora SQL zostanie utracona. Na prawdę chcesz zmienić zapytanie?</translation>
    </message>
</context>
<context>
    <name>CreateTriggerDialog</name>
    <message>
        <location filename="../createtriggerdialog.cpp" line="46"/>
        <source>Error while creating trigger: %2.

%3</source>
        <translation>Wystąpił błąd podczas tworzenia triggera: %2.

%3</translation>
    </message>
    <message>
        <location filename="../createtriggerdialog.cpp" line="49"/>
        <source>Trigger created successfully</source>
        <translation>Trigger został utworzony</translation>
    </message>
    <message>
        <location filename="../createtriggerdialog.ui" line="13"/>
        <source>Create Trigger</source>
        <translation>Utwórz trigger</translation>
    </message>
    <message>
        <location filename="../createtriggerdialog.ui" line="25"/>
        <source>C&amp;reate</source>
        <translation>U&amp;twórz </translation>
    </message>
</context>
<context>
    <name>CreateViewDialog</name>
    <message>
        <location filename="../createviewdialog.cpp" line="49"/>
        <source>Error while creating view: %2.

%3</source>
        <translation>Wystąpił błąd podczas tworzenia widoku: %2.

%3</translation>
    </message>
    <message>
        <location filename="../createviewdialog.cpp" line="52"/>
        <source>View created successfully</source>
        <translation>Widok został utworzony</translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="13"/>
        <source>Create View</source>
        <translation>Utwórz widok</translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="46"/>
        <source>C&amp;reate</source>
        <translation>U&amp;twórz</translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="78"/>
        <source>&amp;Select Statement (AS)</source>
        <translation>Wyrażenie &amp;Select (AS)</translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="96"/>
        <source>&amp;Database:</source>
        <translation>Baza &amp;Danych:</translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="112"/>
        <source>&amp;View Name:</source>
        <translation>Nazwa &amp;widoku:</translation>
    </message>
</context>
<context>
    <name>DataExportDialog</name>
    <message>
        <location filename="../dataexportdialog.cpp" line="34"/>
        <source>Comma Separated Values (CSV)</source>
        <translation>Wartości rozdzielone przecinkiem (CSV)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="35"/>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="36"/>
        <source>MS Excel XML (XLS)</source>
        <translation>MS Excel XML (XLS)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="113"/>
        <source>Export Error</source>
        <translation>Błąd podczas eksportowania</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="114"/>
        <source>Cannot open file %1 for writting</source>
        <translation>Nie można otworzyć pliku %1 do zapisu</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="298"/>
        <source>Comma Separated Value (*.csv)</source>
        <translation>Wartości rozdzielone przecinkiem (*.csv)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="300"/>
        <source>HTML (*.html)</source>
        <translation>HTML (*.html)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="302"/>
        <source>MS Excel XML (*.xml)</source>
        <translation>MS Excel XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="309"/>
        <source>Export to File</source>
        <translation>Eksport do pliku</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="13"/>
        <source>Export Data</source>
        <translation>Eksport danych</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="118"/>
        <source>File:</source>
        <translation>Plik:</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="128"/>
        <source>S&amp;earch...</source>
        <translation>&amp;Szukaj...</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="140"/>
        <source>&amp;Format:</source>
        <translation>&amp;Format:</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="158"/>
        <source>Export to:</source>
        <translation>Eksportuj do:</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="165"/>
        <source>F&amp;ile</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="175"/>
        <source>Cli&amp;pboard</source>
        <translation>Cli&amp;pboard</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="37"/>
        <source>SQL inserts</source>
        <translation>SQL</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="38"/>
        <source>Python List</source>
        <translation>Python</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="304"/>
        <source>SQL inserts (*.sql)</source>
        <translation>SQL (*.sql)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="306"/>
        <source>Python list (*.py)</source>
        <translation>Python (*.py)</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="38"/>
        <source>Export Options</source>
        <translation>Opcje Eksportu</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="50"/>
        <source>If it is checked the table header will be exported with the data too.</source>
        <translation>Jeśli jest zaznaczone to razem z tabelą będzie eksportowany także nagłówek.</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="53"/>
        <source>&amp;Export Headers Too</source>
        <translation>&amp;Eksportuj razem z nagłówkiem</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="63"/>
        <source>Specify the output encoding. UTF-8 is a good choice for most exports.</source>
        <translation>Wybierz rodzaj kodowania. W większości przypadków UTF-8 jest najlepszym wyborem.</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="70"/>
        <source>E&amp;ncoding:</source>
        <translation>Kodowa&amp;nie:</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="80"/>
        <source>&amp;Line End:</source>
        <translation>Koniec &amp;linii:</translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="90"/>
        <source>You can choose the End of Line style here.</source>
        <translation>Tutaj możesz wybrać znak końca linii.</translation>
    </message>
</context>
<context>
    <name>DataViewer</name>
    <message>
        <location filename="../dataviewer.cpp" line="148"/>
        <source>Sqliteman</source>
        <translation>Sqliteman</translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="109"/>
        <source>Are you sure you want to remove all content from this table?</source>
        <translation>Jesteś pewien, że chcesz usunąć całą zawartość z tej tabeli?</translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="123"/>
        <source>Export Error</source>
        <translation>Błąd podczas eksportowania</translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="123"/>
        <source>Data export failed</source>
        <translation>Błąd podczas eksportowania danych</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="13"/>
        <source>Data Viewer</source>
        <translation>Przeglądarka danych</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="72"/>
        <source>New Row</source>
        <translation>Nowy rekord</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="77"/>
        <source>Remove Row</source>
        <translation>Usuń rekord</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="82"/>
        <source>Truncate Table</source>
        <translation>Wyczyść tabelę</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="87"/>
        <source>Export Data</source>
        <translation>Eksport danych</translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="151"/>
        <source>There is a pending transaction in progress. That cannot be commited now.
Error: %1
Perform rollback?</source>
        <translation>Transakcja została rozpoczęta i nie może byc teraz zamknięta.
Błąd: %1
Anulować transakcję?</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="92"/>
        <source>Commit</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="95"/>
        <source>Commit the current transaction in the result table</source>
        <translation>Zamknij bieżącą transakcję</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="100"/>
        <source>Rollback</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="103"/>
        <source>Rollback the current transaction in the result table</source>
        <translation>Anuluj bieżącą transakcję</translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="43"/>
        <source>There is a pending transaction in progress. Perform commit?

Help:
Yes = commit
No = rollback
Cancel = skip this operation and stay in the current table</source>
        <translation>Istnieje transakcja, która nie została zakończona.

Pomoc:
Tak = zatwierdź zmiany
Nie = cofnij zmiany
Anuluj = wróć z powrotem do tabeli</translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <location filename="../database.cpp" line="20"/>
        <source>SQL Error</source>
        <translation>Błąd SQLa</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="28"/>
        <source>Error executing: %1.</source>
        <translation>Wystąpił błąd podczas wykonywania: %1.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="46"/>
        <source>Cannot get databases list. %1</source>
        <translation>Nie można pobrać listy baz danych.%1</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="61"/>
        <source>Error while dropping table %1: %2.</source>
        <translation>Wystąpił błąd podczas usuwania tabeli %1: %2.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="74"/>
        <source>Error while getting the fileds of %1: %2.</source>
        <translation>Wystąpił błąd podczas pobierania pól z %1: %2.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="105"/>
        <source>Error while the list of %1: %2.</source>
        <translation>Wystąpił błąd podczas listowania %1: %2.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="144"/>
        <source>Error while the list of the system catalogue: %2.</source>
        <translation>Wystąpił błąd podczas listowania katalogu systemowego: %2.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="156"/>
        <source>Error while dropping the view %1: %2.</source>
        <translation>Wystąpił błąd podczas usuwania widoku %1: %2.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="169"/>
        <source>Error while dropping the index %1: %2.</source>
        <translation>Wystąpił błąd podczas usuwania indeksu %1: %2.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="181"/>
        <source>Unable to open file %1 for writing.</source>
        <translation>Nie można otworzyć pliku %1 do zapisu.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="193"/>
        <source>Error while exporting SQL: %1.</source>
        <translation>Wystąpił błąd podczas eksportowania SQL: %1.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="211"/>
        <source>Error while dropping the trigger %1: %2.</source>
        <translation>Wystąpił błąd podczas usuwania triggera %1: %2.</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../helpbrowser.ui" line="13"/>
        <source>Sqliteman Help</source>
        <translation>Pomoc Sqliteman</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="63"/>
        <source>&amp;Document</source>
        <translation>&amp;Dokument</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="85"/>
        <source>&amp;Back</source>
        <translation>&amp;Powrót</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="90"/>
        <source>&amp;Forward</source>
        <translation>&amp;Dalej</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>LiteManWindow</name>
    <message>
        <location filename="../litemanwindow.cpp" line="133"/>
        <source>&amp;New...</source>
        <translation>&amp;Nowy...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="134"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="137"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="138"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="141"/>
        <source>&amp;Recent Databases</source>
        <translation>O&amp;statnio używane Bazy</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="148"/>
        <source>E&amp;xit</source>
        <translation>&amp;Koniec</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="149"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="152"/>
        <source>&amp;About...</source>
        <translation>&amp;O...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="155"/>
        <source>&amp;Help Content...</source>
        <translation>Zawartość &amp;pomocy...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="156"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="159"/>
        <source>&amp;SQL Editor</source>
        <translation>Edytor &amp;SQL</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="160"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="169"/>
        <source>&amp;Build Query...</source>
        <translation>U&amp;twórz zapytanie...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="170"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="" line="135061404"/>
        <source>&amp;Export SQL...</source>
        <translation type="obsolete">&amp;Eksport SQL...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="179"/>
        <source>&amp;Create Table...</source>
        <translation>U&amp;twórz tabelę...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="180"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="183"/>
        <source>&amp;Drop Table</source>
        <translation>&amp;Usuń tabelę</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="186"/>
        <source>&amp;Alter Table...</source>
        <translation>&amp;Edytuj tabelę...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="187"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="190"/>
        <source>Create &amp;View...</source>
        <translation>Utwórz &amp;widok...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="191"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="194"/>
        <source>&amp;Drop View</source>
        <translation>&amp;Usuń widok</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="197"/>
        <source>&amp;Alter View...</source>
        <translation>&amp;Edytuj widok...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="200"/>
        <source>&amp;Create Index...</source>
        <translation>U&amp;twórz indeks...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="203"/>
        <source>&amp;Drop Index</source>
        <translation>&amp;Usuń indeks</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="206"/>
        <source>D&amp;escribe Table</source>
        <translation>&amp;Opisz tabelę</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="209"/>
        <source>&amp;Create Trigger...</source>
        <translation>U&amp;twórz trigger...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="212"/>
        <source>&amp;Alter Trigger...</source>
        <translation>&amp;Edytuj trigger...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="215"/>
        <source>&amp;Drop Trigger</source>
        <translation>&amp;Usuń trigger</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="218"/>
        <source>D&amp;escribe Trigger</source>
        <translation>&amp;Opisz trigger</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="221"/>
        <source>D&amp;escribe View</source>
        <translation>&amp;Opisz widok</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="224"/>
        <source>D&amp;escribe Index</source>
        <translation>&amp;Opisz indeks</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="227"/>
        <source>&amp;Reindex</source>
        <translation>&amp;Reindeksuj</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="230"/>
        <source>&amp;Analyze Statistics...</source>
        <translation>&amp;Statystyki...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="233"/>
        <source>&amp;Vacuum...</source>
        <translation>&amp;Kompaktuj...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="236"/>
        <source>A&amp;ttach Database...</source>
        <translation>&amp;Dołącz bazę danych...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="239"/>
        <source>&amp;Detach Database</source>
        <translation>&amp;Odłącz bazę danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="245"/>
        <source>&amp;Constraint Triggers...</source>
        <translation>&amp;Constraint Triggers...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="251"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="260"/>
        <source>&amp;Context</source>
        <translation>&amp;Kontekst</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="263"/>
        <source>&amp;Database</source>
        <translation>Baza &amp;Danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="274"/>
        <source>&amp;System</source>
        <translation>&amp;System</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="280"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="372"/>
        <source>New Database</source>
        <translation>Nowa baza danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="844"/>
        <source>SQLite database (*)</source>
        <translation>Baza danych SQLite (*)</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="392"/>
        <source>Open Database</source>
        <translation>Otwórz bazę danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="862"/>
        <source>Unable to open or create file %1. It is probably not a database</source>
        <translation>Nie można otworzyć lub utworzyć pliku %1. Prawdopodobnie to nie jest baza danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="444"/>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="447"/>
        <source>Sqliteman - SQLite databases made easy

Version %1
(c) 2007 Petr Vanek</source>
        <translation>Sqliteman - czyni bazę danych SQLite łatwą, prostą i przyjemną

Wersja %1
(c) 2007 Petr Vanek

tłumaczenie: Kamil Leś</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="485"/>
        <source>No SQL statement</source>
        <translation>Brak wyrażenia SQL</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="485"/>
        <source>You are trying to run an undefined SQL query. Hint: select your query in the editor</source>
        <translation>Próbujesz wykonać niezdefiniowane zapytanie. Spróbuj zaznaczyć zapytanie w edytorze</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="508"/>
        <source>Query Error: %1

%2</source>
        <translation>Błąd w zapytaniu: %1

%2</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="511"/>
        <source>Query OK
Row(s) returned: %1

%2</source>
        <translation>Zapytanie w porządku
zwrócono: %1 rekord(y/ów)

%2</translation>
    </message>
    <message>
        <location filename="" line="135061404"/>
        <source>Export SQL</source>
        <translation type="obsolete">Eksport SQL</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="529"/>
        <source>SQL File (*.sql)</source>
        <translation>Plik SQL (*.sql)</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="598"/>
        <source>Are you sure that you wish to drop the table &quot;%1&quot;?</source>
        <translation>Jesteś pewien, że chcesz usunąć tabelę &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="635"/>
        <source>Are you sure that you wish to drop the view &quot;%1&quot;?</source>
        <translation>Jesteś pewien, że chcesz usunąć widok &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="664"/>
        <source>Are you sure that you wish to drop the index &quot;%1&quot;?</source>
        <translation>Jesteś pewien, że chcesz usunąć indeks &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="817"/>
        <source>Query Error: %1</source>
        <translation>Błąd w zapytaniu: %1</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="819"/>
        <source>Query OK
Row(s) returned: %1</source>
        <translation>Zapytanie w porządku
zwrócono: %1 rekord(y/ów)</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="849"/>
        <source>Attach Database</source>
        <translation>Dołącz bazę danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="850"/>
        <source>Enter a Schema Alias:</source>
        <translation>Wprowadź alias:</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="913"/>
        <source>Are you sure that you wish to drop the trigger &quot;%1&quot;?</source>
        <translation>Jesteś pewien, że chcesz usunąć trigger &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="145"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencje...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="173"/>
        <source>&amp;Export Schema...</source>
        <translation>&amp;Eksport schematu...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="176"/>
        <source>&amp;Dump Database...</source>
        <translation>&amp;Zrzut bazy danych...</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="519"/>
        <source>Export Schema</source>
        <translation>Eksport schematu</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="529"/>
        <source>Export Database</source>
        <translation>Eksport bazy danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="543"/>
        <source>The process failed to start. Either the invoked program is missing, or you may have insufficient permissions to invoke the program.</source>
        <translation>Błąd podczas uruchamiania. Albo nie ma takiego programu albo brak wystarczających uprawnień do jego uruchomienia.</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="546"/>
        <source>The process crashed some time after starting successfully.</source>
        <translation>Proces przestał funkcjonować jakiś czas po uruchomieniu.</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="549"/>
        <source>An error occurred when attempting to write to the process. For example, the process may not be running, or it may have closed its input channel.</source>
        <translation>Pojawił się błąd podczas zapisu.Prawdopodobnie proces został zatrzymany albo został zamknięty kanał wejściowy.</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="552"/>
        <source>An error occurred when attempting to read from the process. For example, the process may not be running.</source>
        <translation>Pojawił się błąd podczas odczytu. Prawdopodobnie proces został zatrzymany.</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="555"/>
        <source>An unknown error occurred.</source>
        <translation>Pojawił się nieznany błąd.</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="557"/>
        <source>Error creating the dump. Reason: %1</source>
        <translation>Pojawił się błąd podczas robienia zrzutu. Powód: %1</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="560"/>
        <source>Dump written into: %1</source>
        <translation>Zrzut zapisany do: %1</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="164"/>
        <source>Object &amp;Browser</source>
        <translation>Eksplorator &amp;bazy danych</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="165"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="242"/>
        <source>&amp;Refresh Object Tree</source>
        <translation>Odśwież zawa&amp;rtość</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="504"/>
        <source>Duration: %1 seconds</source>
        <translation>Czas: %1 sekund</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="29"/>
        <source>From Locales</source>
        <translation>Z ustawień systemowych</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="35"/>
        <source>System Predefined</source>
        <translation>Predefiniowany</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="13"/>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="37"/>
        <source>&amp;Look and Feel</source>
        <translation>&amp;Wygląd</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="57"/>
        <source>&amp;Recently Used Databases:</source>
        <translation>&amp;Ostatnio otwarte pliki:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="67"/>
        <source>Count of the items in the Recent menu</source>
        <translation>Liczba ostatnio otwartych plików widocznych w menu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="82"/>
        <source>These features require application restart</source>
        <translation>Zmiana właściwości wymaga restartu programu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Select the application look/GUI theme</source>
        <translation>Wybierz schemat wyglądu aplikacji</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="101"/>
        <source>GUI &amp;Language:</source>
        <translation>&amp;Język interfejsu:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="111"/>
        <source>Select the application interface language</source>
        <translation>Wybierz język interfejsu programu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="118"/>
        <source>GUI &amp;Style:</source>
        <translation>&amp;Styl interfejsu:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="153"/>
        <source>&amp;Data Display</source>
        <translation>&amp;Dane</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="178"/>
        <source>NULL handling</source>
        <translation>Obsługa NULL</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>Highlight the NULL values in the data result table</source>
        <translation>Wyróżnij wartości NULL w tabeli wyników</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>&amp;Use NULL highlighting</source>
        <translation>&amp;Używaj wyróżniania NULL</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Background color of the NULL value cell</source>
        <translation>Kolor tła komórki z wartością NULL</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="203"/>
        <source>B&amp;ackground</source>
        <translation>&amp;Tło</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>&amp;NULL alias:</source>
        <translation>Nazwa dla wartości &amp;NULL:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>Text to be used as a NULL mark</source>
        <translation>Tekst używany jako oznaczenie NULL</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="223"/>
        <source>{null}</source>
        <translation>{null}</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="233"/>
        <source>BLOB handling</source>
        <translation>Obsługa BLOB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="245"/>
        <source>Highlight the BLOB values in the data result table</source>
        <translation>Wyróżnij wartości BLOB w tabeli wyników</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="248"/>
        <source>&amp;Use BLOB highlighting</source>
        <translation>&amp;Używaj wyróżniania BLOB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="255"/>
        <source>Background color of the BLOB value cell</source>
        <translation>Kolor tła komórki z wartością BLOB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="258"/>
        <source>Ba&amp;ckground</source>
        <translation>Tł&amp;o</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="265"/>
        <source>&amp;BLOB alias:</source>
        <translation>Nazwa dla wartości &amp;BLOB:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="275"/>
        <source>Text to be used as a BLOB mark</source>
        <translation>Tekst używany jako oznaczenie BLOB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="278"/>
        <source>{blob}</source>
        <translation>{blob}</translation>
    </message>
</context>
<context>
    <name>QueryEditorDialog</name>
    <message>
        <location filename="../queryeditordialog.cpp" line="75"/>
        <source>Create View</source>
        <translation>Utwórz widok</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="77"/>
        <source>Build Query</source>
        <translation>Zbuduj zapytanie</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="173"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="174"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="179"/>
        <source>View name: </source>
        <translation>Nazwa widoku: </translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="182"/>
        <source>Table to Query: </source>
        <translation>Zapytanie do tabeli: </translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="187"/>
        <source>Match all of the following terms</source>
        <translation>Zaznacz wszystkie z następujących warunków</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="188"/>
        <source>Match any of the following terms</source>
        <translation>Zaznacz niektóre z następujących warunków</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="192"/>
        <source>More</source>
        <translation>Więcej</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="193"/>
        <source>Less</source>
        <translation>Mniej</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="216"/>
        <source>Fields</source>
        <translation>Pola</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="233"/>
        <source>Terms</source>
        <translation>Warunki</translation>
    </message>
</context>
<context>
    <name>SqlEditor</name>
    <message>
        <location filename="../sqleditor.cpp" line="34"/>
        <source>Col: %1 Row: %2/%3</source>
        <translation>Kolumna: %1 Linia: %2/%3</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="128"/>
        <source>Open SQL Script</source>
        <translation>Otwórz skrypt SQL</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="162"/>
        <source>SQL file (*.sql);;All Files (*)</source>
        <translation>Plik SQL (*.sql);;Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="128"/>
        <source>Cannot open file %1</source>
        <translation>Nie można otworzyć pliku %1</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="174"/>
        <source>Save SQL Script</source>
        <translation>Zapisz skrypt SQL</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="174"/>
        <source>Cannot write into file %1</source>
        <translation>Nie można zapisać do pliku %1</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="187"/>
        <source>New File</source>
        <translation>Nowy plik</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="188"/>
        <source>All you changes will be lost. Are you sure?</source>
        <translation>Wszystkie zmiany zostaną utracone. Jesteś pewien?</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="201"/>
        <source>Closing</source>
        <translation type="obsolete">Zamykanie</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="202"/>
        <source>Document has been changed. Do you want do save its content?</source>
        <translation>Dokument został zmieniony. Chcesz zapisać jego zawartość?</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="13"/>
        <source>SqlEditor</source>
        <translation>Edytor SQL</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="58"/>
        <source>&amp;Run SQL</source>
        <translation>&amp;Wykonaj SQL</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="61"/>
        <source>Run SQL (F9)</source>
        <translation>Wykonaj SQL (F9)</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="64"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="69"/>
        <source>Run &amp;Explain</source>
        <translation>&amp;Objaśnij SQL</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="72"/>
        <source>Run Explain (F6)</source>
        <translation>Objaśnij SQL (F6)</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="75"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="80"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="83"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="88"/>
        <source>&amp;Save</source>
        <translation>&amp;Zapisz</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="91"/>
        <source>Save (Ctrl+S)</source>
        <translation>Zapisz (Ctrl+S)</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="94"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="99"/>
        <source>&amp;New</source>
        <translation>&amp;Nowy</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="102"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="107"/>
        <source>Save &amp;As...</source>
        <translation>Zapisz j&amp;ako...</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="112"/>
        <source>Create View</source>
        <translation>Utwórz widok</translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="115"/>
        <source>Create view from the current select statement</source>
        <translation>Utwórz widok z bieżącego wyrażenia</translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="201"/>
        <source>Closing SQL Editor</source>
        <translation>Zamykanie edytora SQL</translation>
    </message>
</context>
<context>
    <name>SqlQueryModel</name>
    <message>
        <location filename="../sqlmodels.cpp" line="158"/>
        <source>NULL value</source>
        <translation>wartość NULL</translation>
    </message>
    <message>
        <location filename="../sqlmodels.cpp" line="168"/>
        <source>BLOB value</source>
        <translation>wartość typu BLOB</translation>
    </message>
</context>
<context>
    <name>SqlTableModel</name>
    <message>
        <location filename="../sqlmodels.cpp" line="43"/>
        <source>NULL value</source>
        <translation>wartość NULL</translation>
    </message>
    <message>
        <location filename="../sqlmodels.cpp" line="55"/>
        <source>BLOB value</source>
        <translation>wartość typu BLOB</translation>
    </message>
</context>
<context>
    <name>TableEditorDialog</name>
    <message>
        <location filename="../tableeditordialog.ui" line="13"/>
        <source>Create Table</source>
        <translation>Utwórz tabelę</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="25"/>
        <source>C&amp;reate</source>
        <translation>U&amp;twórz</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="72"/>
        <source>De&amp;sign</source>
        <translation>&amp;Projektuj</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="97"/>
        <source>Table &amp;Name:</source>
        <translation>&amp;Nazwa tabeli:</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="84"/>
        <source>&amp;Database:</source>
        <translation>Baza &amp;danych:</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="110"/>
        <source>Co&amp;lumns</source>
        <translation>&amp;Kolumny</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="132"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="137"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="142"/>
        <source>Not Null</source>
        <translation>Not Null</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="147"/>
        <source>Default</source>
        <translation>Domyślnie</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="155"/>
        <source>&amp;Add</source>
        <translation>Dod&amp;aj</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="162"/>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="199"/>
        <source>Ad&amp;vanced (SQL)</source>
        <translation>Zaa&amp;wansowane (SQL)</translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="185"/>
        <source>If you need to use an advanced options&lt;br&gt;go to the &quot;&lt;b&gt;Advanced (SQL)&lt;/b&gt;&quot; tab.</source>
        <translation>Jeśli chcesz użyć zaawansowanych opcji&lt;br&gt;kliknij zakładkę: &quot;Zaawansowane (SQL)&lt;/b&gt;.</translation>
    </message>
</context>
<context>
    <name>TableTree</name>
    <message>
        <location filename="../tabletree.cpp" line="14"/>
        <source>Database</source>
        <translation>Baza danych</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="15"/>
        <source>Tables</source>
        <translation>Tabele</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="16"/>
        <source>Indexes</source>
        <translation>Indeksy</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="18"/>
        <source>Views</source>
        <translation>Widoki</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="19"/>
        <source>Triggers</source>
        <translation>Triggery</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="20"/>
        <source>System Catalogue</source>
        <translation>Katalog systemowy</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="17"/>
        <source>System Indexes</source>
        <translation>Indeksy systemowe</translation>
    </message>
</context>
<context>
    <name>TermEditor</name>
    <message>
        <location filename="../queryeditordialog.cpp" line="41"/>
        <source>Contains</source>
        <translation>Zawiera</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="41"/>
        <source>Doesn&apos;t contain</source>
        <translation>Nie zawiera</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="41"/>
        <source>Equals</source>
        <translation>Równe</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="42"/>
        <source>Not equals</source>
        <translation>Nie równe</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="42"/>
        <source>Bigger than</source>
        <translation>Większe od</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="42"/>
        <source>Smaller than</source>
        <translation>Mniejsze od</translation>
    </message>
</context>
<context>
    <name>VacuumDialog</name>
    <message>
        <location filename="../vacuumdialog.ui" line="67"/>
        <source>Vacuum Database</source>
        <translation>Kompaktuj bazę danych</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="25"/>
        <source>Vacuum the Selected Objects</source>
        <translation>Kompaktuj zaznaczone obiekty</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="44"/>
        <source>&amp;Vacuum</source>
        <translation>&amp;Kompaktuj</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="79"/>
        <source>Vacuum &amp;All</source>
        <translation>Kompaktuj &amp;całość</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="99"/>
        <source>Strip unused space from the database.</source>
        <translation>Usuń nieużywane miejsce z bazy danych.</translation>
    </message>
</context>
</TS>
